summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authordg <dg@FreeBSD.org>1994-09-21 18:33:23 +0000
committerdg <dg@FreeBSD.org>1994-09-21 18:33:23 +0000
commitaea51315a74b3e868e62da6c4cfe1f817b470d96 (patch)
treeaa3af31e143ba6ef76235effe4526238996d03c0
parentc6923fe4be63b0b6f601b941b1de9e4ebdd76636 (diff)
downloadFreeBSD-src-aea51315a74b3e868e62da6c4cfe1f817b470d96.zip
FreeBSD-src-aea51315a74b3e868e62da6c4cfe1f817b470d96.tar.gz
From 1.1.5:
>date: 1994/06/15 14:35:30; author: paul; state: Exp; lines: +3 -3 >CHanged MAXMEM to ISMAXMEM for safety
-rw-r--r--sys/i386/isa/if_is.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/sys/i386/isa/if_is.c b/sys/i386/isa/if_is.c
index b2a6e87..1f90292 100644
--- a/sys/i386/isa/if_is.c
+++ b/sys/i386/isa/if_is.c
@@ -11,7 +11,7 @@
* of this software, nor does the author assume any responsibility
* for damages incurred with its use.
*
- * $Id: if_is.c,v 1.25 1994/08/08 13:33:16 davidg Exp $
+ * $Id: if_is.c,v 1.26 1994/08/13 03:50:06 wollman Exp $
*/
/* TODO
@@ -333,15 +333,15 @@ is_attach(isa_dev)
* are only 16 bits wide!
*/
-#define MAXMEM ((NRBUF+NTBUF)*(BUFSIZE) + (NRBUF+NTBUF)*sizeof(struct mds) \
+#define ISMAXMEM ((NRBUF+NTBUF)*(BUFSIZE) + (NRBUF+NTBUF)*sizeof(struct mds) \
+ sizeof(struct init_block) + 8)
- is->init_block = (struct init_block *)malloc(MAXMEM,M_TEMP,M_NOWAIT);
+ is->init_block = (struct init_block *)malloc(ISMAXMEM,M_TEMP,M_NOWAIT);
if (!is->init_block) {
printf("is%d : Couldn't allocate memory for card\n",unit);
}
/*
* XXX -- should take corrective action if not
* quadword alilgned, the 8 byte slew factor in MAXMEM
* allows for this.
*/
OpenPOWER on IntegriCloud
@@ -333,15 +333,15 @@ is_attach(isa_dev)
/*
* XXX -- should take corrective action if not
- * quadword alilgned, the 8 byte slew factor in MAXMEM
+ * quadword alilgned, the 8 byte slew factor in ISMAXMEM
* allows for this.
*/